document.addEventListener('DOMContentLoaded', () => {
  fetchTrades();
});
async function updateTradeResult(id, result) {
  try {
    const { apiKey } = await new Promise((resolve) => {
      chrome.storage.local.get(['apiKey'], resolve);
    });

    if (!apiKey) {
      console.error('❌ No API key found in storage');
      return;
    }
    
    const res = await fetch('https://tvjournal-two.vercel.app/api/trades/update', {
      method: 'POST',
      headers: { 'Content-Type': 'application/json', 'Authorization': `Bearer ${apiKey}` },
      body: JSON.stringify({ id, result })
    });

    if (!res.ok) {
      console.error('Failed to update trade result:', await res.text());
      return;
    }

    console.log(`✅ Trade ${id} updated to "${result}"`);
  } catch (err) {
    console.error('Update error:', err);
  }
}
async function fetchTrades() {
  const list = document.getElementById('trade-list');
  list.innerHTML = 'Loading...';

  try {
    // First try to get cached data
    const cachedData = await new Promise((resolve) => {
      chrome.storage.local.get(['tradesCache', 'tradesCacheTimestamp'], (result) => {
        resolve({
          trades: result.tradesCache,
          timestamp: result.tradesCacheTimestamp
        });
      });
    });

    // Check if we have valid cached data (less than 5 minutes old)
    const CACHE_DURATION = 5 * 60 * 1000; // 5 minutes in milliseconds
    const now = Date.now();
    const isCacheValid = cachedData.trades && 
                        cachedData.timestamp && 
                        (now - cachedData.timestamp < CACHE_DURATION);

    if (isCacheValid) {
      console.log('Using cached trades data');
      renderTrades(cachedData.trades, list);
      return;
    }

    // If no valid cache, fetch from API
    const { apiKey } = await new Promise((resolve) => {
      chrome.storage.local.get(['apiKey'], resolve);
    });

    if (!apiKey) {
      list.innerHTML = '❌ No API key found. Please set it in the settings.';
      return;
    }

    const res = await fetch('https://tvjournal-two.vercel.app/api/trades', {
      headers: {
        'authorization': `Bearer ${apiKey}`,
        'Content-Type': 'application/json'
      },
      mode: 'cors',
      credentials: 'omit'
    });

    if (!res.ok) {
      throw new Error(`API request failed: ${res.status}`);
    }

    const trades = await res.json();

    // Cache the new data
    await new Promise((resolve) => {
      chrome.storage.local.set({
        tradesCache: trades,
        tradesCacheTimestamp: now
      }, resolve);
    });

    renderTrades(trades, list);
  } catch (err) {
    console.error('Error fetching trades:', err);
    list.innerHTML = 'Failed to load trades.';
  }
}

// Separate function to render trades
function renderTrades(trades, list) {
  if (!Array.isArray(trades) || trades.length === 0) {
    list.innerHTML = 'No trades found.';
    return;
  }

  list.innerHTML = '';

  trades.forEach(trade => {
    const div = document.createElement('div');
    div.className = 'trade';
    div.innerHTML = `
      <strong>${trade.symbol} (${trade.direction})</strong><br>
      Entry: ${trade.entry_price}<br>
      SL: ${trade.stop_loss}<br>
      TP: ${trade.take_profit}<br>
      ${trade.notes ? `<em>Notes:</em> ${trade.notes}<br>` : ''}
      ${trade.screenshot_url ? `<img src="${trade.screenshot_url}" />` : ''}
    `;

    const statusSelect = document.createElement('select');
    statusSelect.innerHTML = `
      <option value="">-- Result --</option>
      <option value="win" ${trade.result === 'win' ? 'selected' : ''}>Win</option>
      <option value="loss" ${trade.result === 'loss' ? 'selected' : ''}>Loss</option>
      <option value="breakeven" ${trade.result === 'breakeven' ? 'selected' : ''}>Breakeven</option>
    `;

    statusSelect.onchange = function() {
      updateTradeResult(trade.id, statusSelect.value);
    };

    div.appendChild(statusSelect);
    list.appendChild(div);
  });
}

// Add a refresh button to the popup
document.addEventListener('DOMContentLoaded', () => {
  const refreshButton = document.createElement('button');
  refreshButton.textContent = '🔄 Refresh';
  refreshButton.style.margin = '10px';
  refreshButton.style.padding = '5px 10px';
  refreshButton.onclick = () => {
    // Clear cache and fetch fresh data
    chrome.storage.local.remove(['tradesCache', 'tradesCacheTimestamp'], () => {
      fetchTrades();
    });
  };
  
  document.body.insertBefore(refreshButton, document.getElementById('trade-list'));
  fetchTrades();
});